@@ -22,7 +22,7 @@ import re
 from typing import Any, Dict, List, Optional
 
 from spotify_scraper.browsers.base import Browser
-from spotify_scraper.core.exceptions import URLError, ExtractionError
+from spotify_scraper.core.exceptions import URLError
 from spotify_scraper.core.types import ShowData
 from spotify_scraper.utils.url import (
     convert_to_embed_url,
@@ -133,7 +133,13 @@ class ShowExtractor:
             validate_url(url, expected_type="show")
         except URLError as e:
             logger.error("Invalid show URL: %s", e)
-            return {"ERROR": str(e), "id": "", "name": "", "uri": "", "type": "show"}
+            return {
+                "ERROR": str(e),
+                "id": "",
+                "name": "",
+                "uri": "",
+                "type": "show",
+            }
 
         # Extract show ID for logging
         try:
@@ -168,7 +174,13 @@ class ShowExtractor:
 
         except Exception as e:
             logger.error("Failed to extract show data: %s", e)
-            return {"ERROR": str(e), "id": show_id, "name": "", "uri": "", "type": "show"}
+            return {
+                "ERROR": str(e),
+                "id": show_id,
+                "name": "",
+                "uri": "",
+                "type": "show",
+            }
 
     def _extract_show_data_from_embed(self, page_content: str) -> ShowData:
         """Extract show data from embed page HTML content.
@@ -182,7 +194,8 @@ class ShowExtractor:
         try:
             # Find the __NEXT_DATA__ script tag which contains all the data
             match = re.search(
-                r'<script id="__NEXT_DATA__" type="application/json">([^<]+)</script>', page_content
+                r'<script id="__NEXT_DATA__" type="application/json">([^<]+)</script>',
+                page_content,
             )
             if not match:
                 return {
@@ -218,7 +231,8 @@ class ShowExtractor:
             # Check if we got episode data instead of show data
             if show_entity.get("type") == "episode":
                 logger.warning(
-                    "Embed URL returned episode data instead of show data, attempting to extract show info from episode"
+                    "Embed URL returned episode data instead of show data, "
+                    "attempting to extract show info from episode"
                 )
                 show_data = self._extract_show_data_from_episode(show_entity, data)
 
@@ -243,7 +257,7 @@ class ShowExtractor:
                 ),
                 "media_type": show_entity.get("mediaType", ""),
                 "is_externally_hosted": show_entity.get("isExternallyHosted", False),
-                "explicit": show_entity.get("htmlDescription", "").lower().find("explicit") != -1,
+                "explicit": (show_entity.get("htmlDescription", "").lower().find("explicit") != -1),
             }
 
             # Extract description
@@ -644,4 +658,3 @@ class ShowExtractor:
         """
         show_data = self.extract(url)
         return show_data.get("episodes", [])
-
